"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.privateApi = void 0;

var types = _interopRequireWildcard(require("@babel/types"));

var _constants = _interopRequireDefault(require("./constants"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

// constants

/**
 * Utils service for logging arguments.
 *
 * @private
 * @mixin
 */
const privateApi = {};
/**
 * Utils service for logging arguments sent to logger
 *
 * @mixin
 */

exports.privateApi = privateApi;
const service = {};
/**
 * Get default arguments for logging
 *
 * @param {Object} state - node state
 * @param {LogResourceObj} knownData - object with pre-determined data
 * @return {Array<String>} parameter names that represent a string
 */

privateApi.getDefault = (state, knownData) => {
  const {
    sourceFileName,
    sourceMapTarget
  } = state.file.opts;
  const sourceFile = sourceMapTarget || sourceFileName; // build first argument, will contain file name, line number and column number

  const firstArg = `[${sourceFile}:${knownData.line}:${knownData.column}]`;
  return [types.stringLiteral(firstArg), types.stringLiteral(knownData.name)];
};
/**
 * Get function arguments that represent an Identifier
 *
 * @param {Object} path - node path
 * @return {Array<String>} parameter names that represent an Identifier
 */


privateApi.getFunctionArguments = path => {
  const {
    node: {
      params = []
    } = {}
  } = path;
  return params.filter(param => types.isIdentifier(param)).map(param => param.name);
};
/**
 * Get other arguments that should be added when logging
 *
 * @param {Object} path - node path
 * @param {LogResourceObj} knownData - object with pre-determined data
 * @return {Array<String>} parameter names that represent an Identifier
 */


privateApi.getOtherArguments = (path, knownData) => {
  const argumentsToAdd = [];
  const isCatchClause = types.isCatchClause(path);

  if (isCatchClause) {
    // for the catch we need to add the exception
    argumentsToAdd.push(path.node.param.name);
  } else if (knownData.name === _constants.default.MEMBER_EXPRESSION_CATCH) {
    // for a member expression that is catch we should add his arguments
    argumentsToAdd.push(...privateApi.getFunctionArguments(path));
  }

  return argumentsToAdd.map(identifierName => types.identifier(identifierName));
};
/**
 * Get arguments for the logger call that is inserted.
 *
 * @param {Object} path - node path
 * @param {Object} state - node state
 * @param {LogResourceObj} knownData - object with pre-determined data
 * @return {Array} args
 */


service.get = (path, state, knownData) => privateApi.getDefault(state, knownData).concat(privateApi.getOtherArguments(path, knownData)); // only for testing


var _default = service;
exports.default = _default;