"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.babelPluginAutoLogger = babelPluginAutoLogger;
exports.default = void 0;

var _helperPluginUtils = require("@babel/helper-plugin-utils");

var _setup = _interopRequireDefault(require("./setup"));

var _visitors = _interopRequireDefault(require("./visitors"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// services

/**
 * Babel plugin that will automatically add logging.
 * Used visitors:
 *  - Program
 *  -- needed to insert import declaration
 *  - Function
 *  -- needed to insert logging call expression
 *  -- alias for FunctionDeclaration, FunctionExpression, ArrowFunctionExpression, ObjectMethod and ClassMethod
 *  - CatchClause
 *  -- needed to insert logging call expression
 *
 * @param {Object} api - babel api normalization
 *
 * @return {Object} pluginData
 */
function babelPluginAutoLogger(api) {
  api.assertVersion(7); // return plugin data

  return {
    name: 'babel-plugin-auto-logger',
    pre: _setup.default.pre,
    visitor: {
      Program: _visitors.default.program,
      'Function|CatchClause': _visitors.default.insertExpressionStatement
    },
    post: _setup.default.post
  };
} // only for testing


var _default = (0, _helperPluginUtils.declare)(babelPluginAutoLogger);

exports.default = _default;